
--============================================================
--============================================================
--
--             Events
--

IAAM_EVENT_Handlers = {}

--============================================================
--
--             IAAM_CORE_EventHandler()
--
function IAAM_EVENT_GlobalHandler(self, Event, ...)
    IAAM_DEBUG_Print(false, "Core: Event "..Event)
    IAAM_EVENT_Handlers[Event](...)
end

--============================================================
--
--             CHAT_MSG_ADDON()
--
function IAAM_EVENT_Handlers.CHAT_MSG_ADDON(...)
    local Prefix, Data, Channel, Sender, Target, _, _, Name, _  = ...;
    --
    -- Remove realm form name
    --
    Sender = IAAM_CORE_RemoveRealmFromName(Sender)
    --
    -- Extract link and remove link string from data string
    --
    local Link, Data = IAAM_LINK_Get(Data)
    --
    -- Create a table with all arguments
    --
    local Table = IAAM_CORE_GetData(Data)
    --
    -- Table[1] contains the communication command
    --
    local Command = Table[1]
    if Command == IAAM_COM_COMMAND_Item then
        --
        -- Item received
        --
        --                                               Link  Count     Price     CountAvailable
        IAAM_CORE_AddItem(IAAM_Merchant.ItemsForSale, Link, Table[2], Table[3], Table[4])
        -- -IAAM_Frame.Name = Sender
        if IAAM_Frame:IsShown() == false then
            IAAM_Frame:Show()
        end
        IAAM_FRAME_Update()
    elseif Command == IAAM_COM_COMMAND_Query then
        --
        -- Query received from a player.
        -- Send your merchant information.
        --
        for Key, ItemForSale in pairs(IAAM_Character.ItemsForSale) do
            IAAM_COM_SendItem(Sender, ItemForSale.Link, ItemForSale.Count, ItemForSale.Price)
        end
    elseif Command == IAAM_COM_COMMAND_Advertise then
        --
        -- Received advertising. Add player to merchant list and re-advertise.
        --
        if IAAM_CORE_MerchantList[Sender] == nil then
            IAAM_CORE_MerchantList[Sender]        = {}
        end
        IAAM_CORE_MerchantList[Sender].Name       = Sender
        IAAM_CORE_MerchantList[Sender].ItemCount  = Table[2]
        IAAM_CORE_MerchantList[Sender].IsMerchant = true
        IAAM_COM_ReAdvertise(Sender)
        if IAAM_CORE_MerchantList[Sender].ItemCount > 0 then
            IAAM_NAMEPLATE_Update(Sender)
        end
    elseif Command == IAAM_COM_COMMAND_ReAdvertise then
        --
        -- Received re-advertising. Add player to merchant.
        --
        if IAAM_CORE_MerchantList[Sender] == nil then
            IAAM_CORE_MerchantList[Sender]        = {}
        end
        IAAM_CORE_MerchantList[Sender].Name       = Sender
        IAAM_CORE_MerchantList[Sender].ItemCount  = Table[2]
        IAAM_CORE_MerchantList[Sender].IsMerchant = true
        if IAAM_CORE_MerchantList[Sender].ItemCount > 0 then
            IAAM_NAMEPLATE_Update(Sender)
        end
    end
end

--=============================================================
--
--             NAME_PLATE_UNIT_ADDED()
--
function IAAM_EVENT_Handlers.NAME_PLATE_UNIT_ADDED(UnitID)
    if IAAM_CORE_IsValidPlayer(UnitID) then
        IAAM_NAMEPLATE_Initialize(UnitID)
        IAAM_COM_Advertise(IAAM_CORE_GetName(UnitID))
    end
end

--=============================================================
--
--             NAME_PLATE_UNIT_REMOVED()
--
function IAAM_EVENT_Handlers.NAME_PLATE_UNIT_REMOVED(UnitID)
    if UnitIsPlayer(UnitID) then
        IAAM_NAMEPLATE_RemoveMark(UnitID)
    end
end

--=============================================================
--
--             VARIABLES_LOADED()
--
--  Secondary entry point of this addon
--
function IAAM_EVENT_Handlers.VARIABLES_LOADED(event, ...)
    IAAM_DEBUG_Print(false, "Core: Variables loaded")
    
    if type(IAAM_Merchant) ~= "table" then
        IAAM_Merchant = {}
    end
    if type(IAAM_Merchant.ItemsForSale) ~= "table" then
        IAAM_Merchant.ItemsForSale = {}
    end
    if type(IAAM_Character) ~= "table" then
        IAAM_Character = {}
    end
    if type(IAAM_Character.ItemsForSale) ~= "table" then
        IAAM_Character.ItemsForSale = {}
    end
    if IAAM_Character.IsEnabled == nil then
        IAAM_Character.IsEnabled = true
    end
    if type(IAAM_Account) ~= "table" then
        IAAM_Account = {}
    end
    if type(IAAM_Account.Merchants) ~= "table" then
        IAAM_Account.Merchants = {}
    end
    IAAM_COM_Init()
    print("IAmAMerchant (v"..IAAM_VERSION..")")
end