--============================================================
--============================================================
--
--             Global variables
--

--
-- This table stores the WoW Frames. If a player 
-- is visible via his nameplate, a frame will be 
-- created for his nameplate index. Once the frame
-- is created it will be stored here and always
-- reused. This way it's possible to have more
-- control on whether a mark shall be shown or
-- hidden.
--
IAAM_NAMEPLATE_MarkFrames = {}

--============================================================
--============================================================
--
--             Global functions
--

--=============================================================
--
--             IAAM_NAMEPLATE_Initialize()
--
function IAAM_NAMEPLATE_Initialize(UnitID)
    local Nameplate = C_NamePlate.GetNamePlateForUnit(UnitID) 
    --
    -- Check whether nameplate frame already exists.
    -- If not, create one.
    --
    if IAAM_NAMEPLATE_MarkFrames[UnitID] == nil then
        IAAM_NAMEPLATE_MarkFrames[UnitID] = CreateFrame("Frame", "MerchantMark")
        IAAM_NAMEPLATE_MarkFrames[UnitID]:SetFrameStrata("BACKGROUND")
        IAAM_NAMEPLATE_MarkFrames[UnitID]:SetWidth(24)
        IAAM_NAMEPLATE_MarkFrames[UnitID]:SetHeight(24)
        local Texture = IAAM_NAMEPLATE_MarkFrames[UnitID]:CreateTexture(nil, "BACKGROUND")
        Texture:SetTexture("Interface/Store/category-icon-bag.blp")
        Texture:SetAllPoints(IAAM_NAMEPLATE_MarkFrames[UnitID])
        IAAM_NAMEPLATE_MarkFrames[UnitID].texture = Texture
        -- Frame:SetPoint("CENTER", Nameplate.UnitFrame.name, "LEFT", -(Frame:GetWidth()/2), 0)
    end
end

--=============================================================
--
--             IAAM_NAMEPLATE_Removed()
--
function IAAM_NAMEPLATE_Removed(UnitID)
    IAAM_NAMEPLATE_Update(IAAM_CORE_GetName(UnitID))
end

--=============================================================
--
--             IAAM_NAMEPLATE_AddMark()
--
function IAAM_NAMEPLATE_AddMark(UnitID)
    IAAM_DEBUG_Print(false, "IAAM_NAMEPLATE_AddMark(", UnitID, ")")
    local Nameplate = C_NamePlate.GetNamePlateForUnit(UnitID)
    if Nameplate ~= nil and IAAM_Character.IsEnabled then
        IAAM_NAMEPLATE_MarkFrames[UnitID]:ClearAllPoints()
        IAAM_NAMEPLATE_MarkFrames[UnitID]:SetPoint("CENTER", Nameplate.UnitFrame.name, "LEFT", -(IAAM_NAMEPLATE_MarkFrames[UnitID]:GetWidth()/2), 0)
        IAAM_NAMEPLATE_MarkFrames[UnitID]:Show()
        IAAM_DEBUG_Print(false, "Added", IAAM_CORE_GetName(UnitID))
    end
end

--=============================================================
--
--             IAAM_NAMEPLATE_RemoveMark()
--
function IAAM_NAMEPLATE_RemoveMark(UnitID)
    IAAM_DEBUG_Print(false, "IAAM_NAMEPLATE_RemoveMark(", UnitID, ")")
    if IAAM_NAMEPLATE_MarkFrames[UnitID] ~= nil then
        --IAAM_NAMEPLATE_MarkFrames[UnitID]:ClearAllPoints()
        --IAAM_NAMEPLATE_MarkFrames[UnitID]:SetPoint("CENTER", UIParent, "LEFT", -(IAAM_NAMEPLATE_MarkFrames[UnitID]:GetWidth()/2), 0)
        --IAAM_NAMEPLATE_MarkFrames[UnitID].Icon:SetTexture(nil)
        IAAM_NAMEPLATE_MarkFrames[UnitID]:Hide()
    end
end

--=============================================================
--
--             IAAM_NAMEPLATE_Update()
--
function IAAM_NAMEPLATE_Update(UnitName)
    IAAM_DEBUG_Print(false, "IAAM_NAMEPLATE_Update("..UnitName..")")
    for k, v in pairs(IAAM_NAMEPLATE_MarkFrames) do
        local Name = IAAM_CORE_GetName(k)
        if Name == UnitName then
            IAAM_NAMEPLATE_AddMark(k)
        end
    end
end

--=============================================================
--
--             IAAM_NAMEPLATE_HideAll()
--
function IAAM_NAMEPLATE_HideAll()
    IAAM_DEBUG_Print(false, "IAAM_NAMEPLATE_HideAll()")
    for k, v in pairs(IAAM_NAMEPLATE_MarkFrames) do
        v:Hide()
    end
end
